/*
 * Copyright 2013 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtQuick.LocalStorage 2.0

import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1

Rectangle {
    width: units.gu(40)
    height: units.gu(60)

    Label {
        id: title
        ItemStyle.class: "title"
        text: "Notes"
    }
    DataModel{
        id: dataModel
    }

    Component {
        id: newItem
        Header {
            text: "New Item"
            height: units.gu(5)
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    dataModel.newNote("This is a new item with autotext.");
                }
            }
        }
    }
    Component {
        id: noteItem
        Column {
            property int index
            property int dbId: dataModel.get(index).id
            anchors {
                left: parent ? parent.left : undefined
                top: parent ? parent.top : undefined
                right: parent ? parent.right : undefined
            }
            height: childrenRect.height

            Standard {
                height: units.gu(3)
                control: Button {
                    text: dataModel.get(index).date
                    width: parent.width - units.gu(5)
                }

                onClicked: {
                    noteText.readOnly = !noteText.readOnly;
                    if (noteText.readOnly)
                        dataModel.touchNote(dbId, noteText.text)
                }
                progression: true

            }
            TextArea {
                id: noteText
                text: dataModel.get(index).note
                readOnly: true;
                width: parent.width
                // autoexpand forever
                autoExpand: true
                maximumLineCount: 0
            }
        }
    }

    Rectangle {
        color: "lightgray"
        anchors.fill: parent
        anchors.topMargin: title.height
        ListView {
            clip: true
            id: noteList
            anchors.fill: parent
            model: dataModel
            delegate: Loader {
                width: ListView.view.width
                sourceComponent: (id <= 0) ? newItem : noteItem
                onStatusChanged: {
                    if (status == Loader.Ready && item) {
                        item.width = width;
                        height = Qt.binding(function (fx) { return item.height; });
                        if (item.hasOwnProperty("index"))
                            item.index = index;
                    }
                }
            }
        }
    }
}
