/*
 * Copyright 2013 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.HUD 0.1 as HUD
import "Components"
import "Models"

MainView {
    id: window
    width: units.gu(40)
    height: units.gu(71)

    HUD.HUD {
        applicationIdentifier: "notes-app" // this has to match the .desktop file!
        HUD.Context {
            toolbar.quitAction.onTriggered: Qt.quit()
            HUD.Action {
                label: "Add"
                keywords: "Create New Note"
            }
            HUD.Action {
                label: "Delete"
                keywords: "Trash;Erase Note"
            }
        }
    }

    Component.onCompleted: Theme.loadTheme(Qt.resolvedUrl("notes-app.qmltheme"))

    Page {
        anchors.fill: parent
        title: "Notes"

        tools: ToolbarActions {
            id: actions
            Action {
                text: "Add"
                iconSource: Qt.resolvedUrl("Components/graphics/add.png")
                onTriggered: {
                    window.toolbar.active = false

                    // Don't create a new note if there's only one and it's empty already,
                    // but ensure it's activated so that the user can start typing
                    if (dataModel.count === 1 &&
                        noteList.commitNote(0, false).length === 0) {
                    } else {
                        dataModel.newNote();
                    }
                    noteList.setActiveIndex(0);
                }
            }
        }

        // model to access the database of Notes
        DataModel {
            id: dataModel
        }

        // background
        Rectangle {
            anchors.fill: parent
            color: "#fff6e5"
        }

        Flickable {
            anchors.fill: parent
            contentHeight: spacer.height
            contentWidth: width

            flickableDirection: Flickable.VerticalFlick

            Item {
                /* The only purpose of this Item is to add a 2gu space
                   between the header and the content */
                id: spacer
                height: noteList.height + units.gu(2)
                anchors.left: parent.left
                anchors.right: parent.right

                NoteList {
                    id: noteList
                    anchors.left: parent.left
                    anchors.right: parent.right
                    anchors.top: parent.top
                    anchors.topMargin: units.gu(2)
                }
            }
        }
    }
}
