# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# Copyright 2012 Canonical
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

"""notes-app autopilot tests."""

from os import remove
import os.path
import glob

from autopilot.introspection.qt import QtIntrospectionTestMixin
from autopilot.testcase import AutopilotTestCase

from notes_app.emulators.main_window import MainWindow

class NotesAppTestCase(AutopilotTestCase, QtIntrospectionTestMixin):

    """A common test case class that provides several useful methods for notes app tests."""

    def setUp(self):
        super(NotesAppTestCase, self).setUp()
        # Lets assume we are installed system wide if this file is somewhere in /usr
        print os.path.realpath(__file__)
        if os.path.realpath(__file__).startswith("/usr/"):
            self.launch_test_installed()
        else:
            self.launch_test_local()

    """Workaround to find the qmlscene binary via shell globbing.
       This is needed since we can't rely on qt5-default being installed on
       devices to make qmlscene available in the path"""
    def qmlscene(self):
        return glob.glob("/usr/lib/*/qt5/bin/qmlscene")[0]

    def launch_test_local(self):
        self.app = self.launch_test_application(self.qmlscene(),
            "../../NotesApp.qml")

    def launch_test_installed(self):
        self.app = self.launch_test_application(self.qmlscene(),
            "/usr/share/notes-app/NotesApp.qml")

    @staticmethod
    def running_on_device():
        return os.path.isfile('/system/usr/idc/autopilot-finger.idc')

    @property
    def main_window(self):
        return MainWindow(self.app)




